<?php
namespace Teknisa\CTB\Controllers;

use Teknisa\CTB\Services\Ctb17000ImplantacaoSaldoService;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;

class Ctb17000ImplantacaoSaldoController extends \Teknisa\CTB\Controllers\TeknisaCrud {

    protected $dataSourceName = "implantsaldo_empresa";
    protected $parameterBagColumns = array();

    public function __construct($crudService, ParameterBag $parameterBag, Ctb17000ImplantacaoSaldoService $implantacaoService) {
        $this->implantacaoService = $implantacaoService;
        parent::__construct($crudService, $parameterBag);
    }

    public function findImplantSaldoEmpresa(DTO\Request\Filter $request, DTO\Response $response){
        try{
            $this->dataSourceName = "implantsaldo_empresa";
            $this->parameterBagColumns = array("CDEMPRESA", "DTSALDO", "CDCONTCTBLINI", "CDCONTCTBLFIN", "NRORG");

            parent::find($request, $response);
        }catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getSequencial(DTO\Request\Row $request, DTO\Response $response){
        try{
            $result = $this->implantacaoService->getSequencial();
            $dataSet = new DataSet('dataSetSequencial', array("NRSEQUENCIAL" => $result));
            $response->addDataSet($dataSet);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function save(DTO\Request $request, DTO\Response $response){
        try{
            $dataSet = $request->getDataSet();
            $row = $dataSet->getRows()[0];
            $this->implantacaoService->getVdImplantSaldo($row);
            if ($row['__is_new']) {
                parent::save($request, $response);
            } else {
                $this->implantacaoService->Update($row);
            }
            $columnsToReturn = $this->crudService->getColumnsToReturn();
            if ($row['__is_new']) {
                $response->addDataset(new DataSet('columnsToReturn', $columnsToReturn[0]));
            }
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
}