<?php

namespace Teknisa\CTB\Controllers;

use Teknisa\CTB\Services\Ger09400ParametroContabilService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request\Row; 
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\CTB\Controllers\EntityManager;
use Teknisa\Libs\Util\Environment;

class Ger09400ParametroContabilController{
    
    protected $ger09400ParametroContabilService;
    protected $entityManager;
    protected $connection;
    
    public function __construct(\Doctrine\ORM\EntityManager $entityManager, Environment $environment, Ger09400ParametroContabilService $ger09400ParametroContabilService){
        $this->ger09400ParametroContabilService = $ger09400ParametroContabilService;
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }
    
    public function cadastramentoAutomatico(Row $row, Response $response){
        $this->entityManager->beginTransaction();
        try{
            $row = $row->getRow();
            foreach($row['CDEMPRESA'] as $cdempresa){
                $this->ger09400ParametroContabilService->cadastramentoAutomatico($row, $cdempresa);
                $this->entityManager->flush();
            }
            $this->entityManager->commit();
        }
        catch (\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function validateSaldoPositivo( Row $request, Response $response){
         try {
            $row = $request->getRow();

            // Busca os arrays de dados.
            $saldo = array();
            foreach($row['CDEMPRESA'] as $cdempresa){
                array_push($saldo, ($this->ger09400ParametroContabilService->validateSaldoPositivo($cdempresa, $row["DTINICCONT"])));
            }

            // Cria os respectivos DataSets.
            $saldoDataSet = new DataSet('saldo', $saldo);

            // Adiciona os DataSets no response da requisição.
            $response->addDataSet($saldoDataSet);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function validateLacnamentoPendenteRecalculo( Row $request, Response $response){
         try {
            $row = $request->getRow();

            // Busca os arrays de dados.
            $lancamento = array();
            foreach($row['CDEMPRESA'] as $cdempresa){
                array_push($lancamento, $this->ger09400ParametroContabilService->validateLacnamentoPendenteRecalculo($cdempresa));
            }

            // Cria os respectivos DataSets.
            $lancamentoDataSet = new DataSet('lancamento', $lancamento);

            // Adiciona os DataSets no response da requisição.
            $response->addDataSet($lancamentoDataSet);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}